@@ -1,7 +1,7 @@
 import os
 import shutil
 import logging
-from modeldeploy_proxy_controller.processors.nbprocessor import NotebookProcessor, REQUIREMENTS_TAG, PREPROCESSORS_TAG, POSTPROCESSORS_TAG, FUNCTIONS_TAG, CVAT_INFO_TAG
+from modeldeploy_proxy_controller.processors.nbprocessor import NotebookProcessor, REQUIREMENTS_TAG, PREPROCESSORS_TAG, POSTPROCESSORS_TAG, FUNCTIONS_TAG, CVAT_INFO_TAG, CVAT_PREPROCESSORS_TAG, CVAT_POSTPROCESSORS_TAG
 from modeldeploy_proxy_controller.rpc.errors import RPCInternalError
 import requests
 
@@ -47,6 +47,22 @@ def parse_notebook(request, source_notebook_path):
         else:
             source = '{}'.format(blocks[CVAT_INFO_TAG][0])
 
+    if len(blocks[CVAT_PREPROCESSORS_TAG]) > 1:
+        raise RuntimeError("CVAT preprocess tag must be at most 1!")
+    elif len(blocks[CVAT_PREPROCESSORS_TAG]):
+        if source:
+            source = '{}{}{}'.format(source, NEW_LINES, blocks[CVAT_PREPROCESSORS_TAG][0])
+        else:
+            source = '{}'.format(blocks[CVAT_PREPROCESSORS_TAG][0])
+
+    if len(blocks[CVAT_POSTPROCESSORS_TAG]) > 1:
+        raise RuntimeError("CVAT postprocess tag must be at most 1!")
+    elif len(blocks[CVAT_POSTPROCESSORS_TAG]):
+        if source:
+            source = '{}{}{}'.format(source, NEW_LINES, blocks[CVAT_POSTPROCESSORS_TAG][0])
+        else:
+            source = '{}'.format(blocks[CVAT_POSTPROCESSORS_TAG][0])
+
     if len(blocks[FUNCTIONS_TAG]):
         for function in blocks[FUNCTIONS_TAG]:
             if source:
