@@ -11,8 +11,6 @@ TRANSFORMER_UPLOAD_URL = "{}/transformer/upload".format(PROXY_API_PREFIX)
 REQUIREMENTS_UPLOAD_URL = "{}/requirements/upload".format(PROXY_API_PREFIX)
 STATUS_URL = "{}/proxy/health/status".format(PROXY_API_PREFIX)
 
-PROXY_URL_FILE_NAME = ".proxy"
-
 def revise_proxy_api_url(request, proxy_url):
     request.log.debug("revise_proxy_api_url")
 
@@ -61,20 +59,31 @@ def info(request):
     request.log.debug("info")
     cwd = os.getcwd()
     proxy_url = ""
-    path = ""
-    PROXY_URL_NAME = ".proxy"
+    nb_path = ""
+    PROXY_URL_FILE_NAME = ".proxy"
+    TRANSFORMER_NB_FILE_NAME = "transformer.ipynb"
     try:
         for root, dirs, files in os.walk(cwd):
-            if PROXY_URL_NAME in files:
-                path = os.path.join(root, PROXY_URL_NAME)
+            if PROXY_URL_FILE_NAME in files:
+                path = os.path.join(root, PROXY_URL_FILE_NAME)
                 proxy_url = open(path).readline().strip()
                 break
     except Exception:
         pass
 
+    request.log.debug("proxy_url: {}".format(proxy_url))
+    try:
+        for root, dirs, files in os.walk(cwd):
+            if TRANSFORMER_NB_FILE_NAME in files:
+                nb_path = os.path.join(root, TRANSFORMER_NB_FILE_NAME)
+                break
+    except Exception:
+        pass
+    request.log.debug("nb_path: {}".format(nb_path))
+
     UNAVAILABLE = "Unavailable"
     info = {
-        "directory": cwd,
+        "nb_path": nb_path,
         "proxy_url": proxy_url,
         "proxy_status": UNAVAILABLE
     }
