@@ -3,7 +3,7 @@ import logging
 import importlib
 from modeldeploy_proxy_controller.common.utils import random_string
 from modeldeploy_proxy_controller.rpc import errors, utils
-from modeldeploy_proxy_controller.rpc.log import create_adapter
+from modeldeploy_proxy_controller.rpc.log import create_adapter, setup_logging
 
 logger = create_adapter(logging.getLogger(__name__))
 
@@ -54,6 +54,7 @@ def run(func, kwargs, ctx):
     """
     # Setup initial request obj to have something to log to
     request = ModelDeploymentControllerRPCRequest()
+    setup_logging(request)
     request.log.debug("Decoding ctx of RPC function '%s'", func)
     try:
         ctx = utils.deserialize(ctx)
